@@ -205,6 +205,8 @@ class TestBitbake:
             "artifacts": [],
             "environment": {},
             "local_conf": [],
+            "targets": None,
+            "name": "",
             "bblayers_conf": [],
             "container": bitbake.build_definition.container,
             "manifest": None,
@@ -232,6 +234,8 @@ class TestBitbake:
                     "url": "https://github.com/96boards/oe-rpb-manifest.git",
                 },
                 "target": "rpb-console-image rpb-console-image-test rpb-desktop-image rpb-desktop-image-test",
+                "targets": None,
+                "name": "",
                 "artifacts": [],
                 "environment": {},
                 "local_conf": [],
@@ -251,6 +255,16 @@ class TestBitbake:
         assert isinstance(type(result[0]), type(str))
         assert base64.b64decode(result[1]) == sample_manifest.encode("utf-8")
 
+    def test_handle_manifest_unknown(self, mocker, sample_manifest_file):
+        guess = mocker.patch(
+            "mimetypes.guess_type", return_value=("application/unknown", None)
+        )
+        with pytest.raises(Exception) as e:
+            tuxsuite.build.handle_manifest(sample_manifest_file)
+
+        assert guess.call_count == 1
+        assert str(e.value) == "Manifest format unknown"
+
     def test_handle_manifest_url(self):
         url = "https://test.example.com/url"
         result = tuxsuite.build.handle_manifest(url)
