@@ -833,7 +833,6 @@ def test_plan_cli_options(mocker, plan_config, tuxsuite_config):
     assert download.call_count == 2
     assert show_log.call_count == 2
 
-    print(result)
     assert (
         """Running Linux Kernel plan 'Simple plan': 'A simple plan'
 Plan http://api/v1/groups/grp/projects/prj/plans/1sMUTVjE25tQvDmjJ8SjWblpOJr
@@ -841,8 +840,8 @@ Plan http://api/v1/groups/grp/projects/prj/plans/1sMUTVjE25tQvDmjJ8SjWblpOJr
 uid: 1sMUTVjE25tQvDmjJ8SjWblpOJr
 
 Summary: http://api/v1/groups/grp/projects/prj/plans/1sMUTVjE25tQvDmjJ8SjWblpOJr
-2 👾 Pass (1 warning) arm64@gcc-11
-1 🎉 Pass arm64@gcc-10 👹 Fail: boot,ltp-smoke"""
+2 👾 Pass (1 warning)
+1 🎉 Pass 👹 Fail: boot,ltp-smoke"""
         in result.output
     )
 
@@ -1080,6 +1079,21 @@ def test_build_no_wait(mocker, tmp_path):
     assert format_result.call_count == 1
 
 
+def test_bake_no_wait(mocker, tmp_path, sample_bitbake_template):
+    template = tmp_path / "yocto.json"
+    template.write_text(sample_bitbake_template)
+    build = mocker.patch("tuxsuite.Bitbake.build")
+    format_result = mocker.patch("tuxsuite.cli.format_result")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxsuite.cli.bake,
+        ["submit", f"{template}", "--no-wait"],
+    )
+    assert result.exit_code == 0
+    assert build.call_count == 1
+    assert format_result.call_count == 1
+
+
 def test_build_set_no_wait(
     mocker, tuxsuite_config, tux_config, tmp_path, plan_builds, plan_builds_status_list
 ):
@@ -1324,10 +1338,10 @@ def test_results_cli(
     assert (
         result.output
         == """Summary: https://tuxapi.tuxsuite.com/v1/groups/tuxsuite/projects/tux/plans/1sMNB0p8a3OrpUmEBgYah0Ycer9
-1sMUTVjE25tQvDmjJ8SjWblpOJr 🎉 Pass arm@gcc-9
-1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (1 warning) arm@gcc-9
-1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (3 warnings) arm@gcc-9
-1sMUTVjE25tQvDmjJ8SjWblpOJr 👹 Fail (1 error) arm@gcc-9
+1sMUTVjE25tQvDmjJ8SjWblpOJr 🎉 Pass with toolchain: gcc-9 target_arch: arm
+1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (1 warning) with toolchain: gcc-9 target_arch: arm
+1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (3 warnings) with toolchain: gcc-9 target_arch: arm
+1sMUTVjE25tQvDmjJ8SjWblpOJr 👹 Fail (1 error) with toolchain: gcc-9 target_arch: arm
 builds (4): 🎉 1 👾 2 👹 1
 tests (1): 👹 1
 """
@@ -1391,10 +1405,10 @@ tests (1): 👹 1
     assert (
         result.output
         == """Summary: https://tuxapi.tuxsuite.com/v1/groups/tuxsuite/projects/tux/plans/null
-1sMUTVjE25tQvDmjJ8SjWblpOJr 🎉 Pass arm@gcc-9
-1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (1 warning) arm@gcc-9
-1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (3 warnings) arm@gcc-9
-1sMUTVjE25tQvDmjJ8SjWblpOJr 👹 Fail (1 error) arm@gcc-9
+1sMUTVjE25tQvDmjJ8SjWblpOJr 🎉 Pass with toolchain: gcc-9 target_arch: arm
+1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (1 warning) with toolchain: gcc-9 target_arch: arm
+1sMUTVjE25tQvDmjJ8SjWblpOJr 👾 Pass (3 warnings) with toolchain: gcc-9 target_arch: arm
+1sMUTVjE25tQvDmjJ8SjWblpOJr 👹 Fail (1 error) with toolchain: gcc-9 target_arch: arm
 builds (4): 🎉 1 👾 2 👹 1
 tests (1): 👹 1
 """
