@@ -477,6 +477,13 @@ class Plan(HeadersMixin):
             self.group, self.project
         )
         self.results = {"builds": {}, "tests": {}}
+        # setting respective plan type class obj
+        if self.config and hasattr(self.config, "plan_type"):
+            self.plan_type = self.config.plan_type
+        else:
+            # setting default plan as BuildPlan ( kernel )
+            # build-set also uses plan, so needed
+            self.plan_type = tuxsuite.BuildPlan()
 
     def submit(self):
         builds = []
@@ -491,30 +498,8 @@ class Plan(HeadersMixin):
             {"name": self.config.name, "description": self.config.description},
         )["uid"]
 
-        # Create the builds
-        for cfg in self.config.plan:
-            if cfg["build"] is not None:
-                data = self.args.copy()
-                data.update(cfg["build"])
-                if self.args.get("no_cache"):
-                    data["no_cache"] = True
-                builds.append(Build(**data))
-            else:
-                builds.append(None)
-
-        builds_to_submit = [b for b in builds if b]
-        if builds_to_submit:
-            req_data = {"builds": [], "patches": {}}
-            for b in builds_to_submit:
-                build_entry, patch = b.generate_build_request(plan=self.plan)
-                req_data["builds"].append(build_entry)
-                req_data["patches"].update(patch)
-            ret = post_request(f"{self.url}/builds", self.headers, req_data)
-            # Updating builds_to_submit will update values in builds
-            for (build, data) in zip(builds_to_submit, ret):
-                build.build_data = data["download_url"]
-                build.uid = data["uid"]
-                build.status = data
+        # calling respective plan type class to create builds
+        self.plan_type.create_builds(self, builds)
 
         # Create the tests
         for (build, cfg) in zip(builds, self.config.plan):
@@ -529,9 +514,10 @@ class Plan(HeadersMixin):
                             project=self.project,
                             device=test["device"],
                             parameters=test.get("parameters", {}),
+                            rootfs=test.get("rootfs"),
                             tests=test.get("tests", []),
-                            boot_args=test.get("boot_args"),
                             timeouts=test.get("timeouts"),
+                            boot_args=test.get("boot_args"),
                             wait_for=build.uid,
                         )
                     )
@@ -627,16 +613,28 @@ class Plan(HeadersMixin):
         builds = {}
         tests = {}
         first = True
-        start_builds = start_tests = None
-        while first or start_builds is not None or start_tests is not None:
+        start_builds = start_oebuilds = start_tests = None
+        while (
+            first
+            or start_builds is not None
+            or start_tests is not None
+            or start_oebuilds is not None
+        ):
             ret = get_request(
                 f"{self.url}/plans/{self.plan}",
                 headers=self.headers,
-                params={"start_builds": start_builds, "start_tests": start_tests},
+                params={
+                    "start_builds": start_builds,
+                    "start_tests": start_tests,
+                    "start_oebuilds": start_oebuilds,
+                },
             )
             if first or start_builds is not None:
                 builds.update({b["uid"]: b for b in ret["builds"]["results"]})
                 start_builds = ret["builds"]["next"]
+            if first or start_oebuilds is not None:
+                builds.update({b["uid"]: b for b in ret["oebuilds"]["results"]})
+                start_oebuilds = ret["oebuilds"]["next"]
             if first or start_tests is not None:
                 tests.update({t["uid"]: t for t in ret["tests"]["results"]})
                 start_tests = ret["tests"]["next"]
@@ -984,6 +982,7 @@ class Bitbake(HeadersMixin):
     @attrs(kw_only=True, order=False)
     class BuildDefinition:
         target = attrib(default=None)
+        targets = attrib(default=None)
         envsetup = attrib(default=None)
         distro = attrib(default=None)
         machine = attrib(default=None)
@@ -994,10 +993,15 @@ class Bitbake(HeadersMixin):
         bblayers_conf = attrib(default=[])
         container = attrib(default="ubuntu-20.04")
         manifest = attrib(default=None)
+        name = attrib(default="")
 
     def __attrs_post_init__(self):
         self.build_definition = self.BuildDefinition(**(self.data))
 
+    # Currently of no use but needed for Plan filters(passing, warnings, failings etc.)
+    def __lt__(self, other):
+        pass
+
     def __str__(self):
         return "{} with {} {} for {}: {} ".format(
             self.build_definition.sources,
@@ -1011,11 +1015,13 @@ class Bitbake(HeadersMixin):
         """return a build data in a python dict"""
         manifests = {}
         build_data = self.build_definition.__dict__
-        if self.build_definition.manifest:
+        if self.build_definition.manifest and plan is None:
             (build_data["manifest_file"], manifest) = handle_manifest(
                 self.build_definition.manifest
             )
             manifests[build_data["manifest_file"]] = manifest
+        if plan is not None:
+            build_data["plan"] = plan
         return (build_data, manifests)
 
     def build(self, plan=None):
