@@ -145,6 +145,27 @@ def plan_summary(plan):
     return (bs, ts)
 
 
+def format_build(build, icon, color, msg):
+    prefix = build.uid + " " + click.style(f"{icon} {msg}", fg=color, bold=True)
+    builds = ""
+    # key: string, value: list ( list can't be empty)
+    build_type_map = {
+        "Build": ["toolchain", "target_arch"],
+        "Bitbake": ["container", "machine", "target"],
+    }
+    # respective build type classnames for kernel or bake builds
+    build_type = build.__class__.__name__
+    if build_type == "Bitbake":
+        build = build.build_definition
+
+    if build_type in build_type_map:
+        for config in build_type_map[build_type]:
+            if config in build.__dict__:
+                builds += " " + config + ": " + str(getattr(build, config))
+
+    return (prefix + " with" + builds) if builds else prefix
+
+
 def format_plan_result(build, tests):
     fail = False
     if build.status["result"] == "pass":
@@ -175,15 +196,7 @@ def format_plan_result(build, tests):
     else:
         raise NotImplementedError()
 
-    builds = (
-        build.uid
-        + " "
-        + click.style(f"{icon} {message}", fg=cli_color, bold=True)
-        + " "
-        + build.target_arch
-        + "@"
-        + build.toolchain
-    )
+    builds = format_build(build, icon, cli_color, message)
 
     tests_str = ""
     tests_pass = sorted(
@@ -227,21 +240,51 @@ def format_plan_result(build, tests):
         info(builds + tests_str)
 
 
-def format_result(result_json, tuxapi_tests_url=None, prefix=""):
-    state = result_states.get(result_json["state"], None)
-    result = result_json["result"]
+def get_result_msg(result_json, tuxapi_tests_url):
     result_msg = ""
     if "build_name" in result_json:
-        result_msg = (
-            f"{result_json['target_arch']} "
-            f"({','.join(result_json['kconfig'])}) "
-            f"with {result_json['toolchain']} @ {result_json['download_url']}"
-        )
+        if (
+            result_json.get("target_arch")
+            and result_json.get("kconfig")
+            and result_json.get("toolchain")
+        ):
+            result_msg = (
+                f"{result_json['target_arch']} "
+                f"({','.join(result_json['kconfig'])}) "
+                f"with {result_json['toolchain']} @ {result_json['download_url']}"
+            )
+    elif "sources" in result_json:
+        if (
+            result_json["sources"].get("repo")
+            or result_json["sources"].get("git_trees")
+        ) and (
+            result_json.get("container")
+            and result_json.get("machine")
+            and result_json.get("target")
+        ):
+            result_msg = (
+                f"with container: {result_json['container']}, "
+                f"machine: {result_json['machine']} and "
+                f"target: {result_json['target']}  @ {result_json['download_url']}"
+            )
+        elif result_json["sources"].get("kas") and result_json.get("container"):
+            result_msg = (
+                f"with container: {result_json['container']}, "
+                f"kas: {result_json['sources']['kas']} @ {result_json['download_url']}"
+            )
+
     elif "tests" in result_json:
         result_msg = (
             f"[{','.join(result_json['tests'])}] "
             f"{result_json['device']} @ {tuxapi_tests_url}"
         )
+    return result_msg
+
+
+def format_result(result_json, tuxapi_tests_url=None, prefix=""):
+    state = result_states.get(result_json["state"], None)
+    result = result_json["result"]
+    result_msg = get_result_msg(result_json, tuxapi_tests_url)
     if state is None:
         errors = 0
         warnings = 0
@@ -333,6 +376,7 @@ def common_options(required):
         "gcc-9",
         "gcc-10",
         "gcc-11",
+        "gcc-12",
         "clang-10",
         "clang-11",
         "clang-12",
@@ -536,10 +580,37 @@ def bake():
     help=(
         "Path to a local manifest file which will be used during repo sync."
         "This input is ignored if sources used is git_trees in the build"
-        "definition. Should be a valid XML"
+        " definition. Should be a valid XML"
     ),
 )
-def submit(build_definition, json_out=None, local_manifest=None):
+@click.option(
+    "-n",
+    "--no-wait",
+    default=False,
+    is_flag=True,
+    help="Don't wait for the builds to finish",
+)
+@click.option(
+    "-d",
+    "--download",
+    default=False,
+    is_flag=True,
+    help="Download artifacts after builds finish. Can't be used with no-wait",
+)
+@click.option(
+    "-o",
+    "--output-dir",
+    default=".",
+    help="Directory where to download artifacts",
+)
+def submit(
+    build_definition,
+    json_out=None,
+    local_manifest=None,
+    no_wait=False,
+    download=False,
+    output_dir=None,
+):
     try:
         with open(os.path.abspath(build_definition)) as reader:
             data = json_lib.load(reader)
@@ -569,7 +640,16 @@ def submit(build_definition, json_out=None, local_manifest=None):
     except tuxsuite.exceptions.BadRequest as e:
         raise (click.ClickException(str(e)))
 
-    build_result = wait_for_object(build)
+    build_result = True
+
+    if no_wait:
+        format_result(build.status)
+    else:
+        build_result = wait_for_object(build)
+
+    if download:
+        tuxsuite.download.download(build, output_dir)
+
     if json_out:
         json_out.write(json_lib.dumps(build.status, sort_keys=True, indent=4))
     if not build_result:
@@ -1072,6 +1152,17 @@ plan_description = (
     is_flag=True,
     help="Show json output. Used with [get | list]",
 )
+@click.option(
+    "-l",
+    "--local-manifest",
+    type=file_or_url,
+    default=None,
+    help=(
+        "Path to a local manifest file which will be used during repo sync. "
+        "This input is ignored if sources used is git_trees in the build "
+        "definition. Should be a valid XML. This option is only applicable in case of bake plan."
+    ),
+)
 @click.argument("action", metavar="[ACTION]", required=False)
 @click.argument("uid", metavar="[UID]", required=False)
 @click.argument("config", required=False)
@@ -1119,6 +1210,10 @@ def plan(
 
     try:
         plan_config = tuxsuite.config.PlanConfig(name, description, config, job_name)
+
+        # setting respective plan type class obj (Kernel or Bake)
+        plan_type = plan_config.plan_type
+
         if plan_config.schema_warning:
             warning(f"Invalid plan file: {plan_config.schema_warning}")
 
@@ -1129,11 +1224,7 @@ def plan(
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
         error(e)
 
-    info(
-        "Running Linux Kernel plan '{}': '{}'".format(
-            plan_config.name, plan_config.description
-        )
-    )
+    plan_type.plan_info(plan_config.name, plan_config.description)
 
     try:
         plan.submit()
